Security Advisories (1)
CVE-2025-40933
(2025-09-17)
Apache::AuthAny::Cookie v0.201 or earlier for Perl generates session ids insecurely. Session ids are generated using an MD5 hash of the epoch time and a call to the built-in rand function. The epoch time may be guessed, if it is not leaked from the HTTP Date header. The built-in rand function is unsuitable for cryptographic usage. Predicable session ids could allow an attacker to gain access to systems.
No POD found for MapToStorageHandler.pm.
Time to read the source?
Module Install Instructions
To install Apache2::AuthAny, copy and paste the appropriate command in to your terminal.
cpanm Apache2::AuthAny
perl -MCPAN -e shell
install Apache2::AuthAny
For more information on module installation, please visit the detailed CPAN module installation guide.